<?php

namespace Shopbydedi\Payment;

/**
 * Class PaypalConfig
 * @package Shopbydedi\Payment
 */
class PaypalConfig
{
    /**
     * @var string
     */
    protected $clientId;
    /**
     * @var string
     */
    protected $clientSecret;
    /**
     * @var string sandbox | live
     */
    protected $mode;
    /**
     * @var string
     */
    protected $urlSuccess;
    /**
     * @var string
     */
    protected $urlFailure;
    /**
     * @var string
     */
    protected $urlNotify;
    /**
     * @var string
     */
    protected $storageDir;

    /**
     * PaypalConfig constructor.
     *
     * @param array $config
     */
    public function __construct(array $config = array())
    {
        if (isset($config['client_id'])) {
            $this->setClientId($config['client_id']);
        }

        if (isset($config['client_secret'])) {
            $this->setClientSecret($config['client_secret']);
        }

        if (isset($config['mode'])) {
            $this->setMode($config['mode']);
        }

        if (isset($config['url_success'])) {
            $this->setUrlSuccess($config['url_success']);
        }

        if (isset($config['url_notify'])) {
            $this->setUrlNotify($config['url_notify']);
        }

        if (isset($config['url_failure'])) {
            $this->setUrlFailure($config['url_failure']);
        }

        if (isset($config['storage_dir'])) {
            $this->setStorageDir($config['storage_dir']);
        }
    }

    /**
     * Check if the config is valid or not
     *
     * @return bool
     */
    public function isValid()
    {
        return (
            !empty($this->getClientId()) &&
            !empty($this->getClientSecret()) &&
            !empty($this->getUrlSuccess()) &&
            !empty($this->getUrlFailure()) &&
            !empty($this->getUrlNotify()) &&
            !empty($this->getStorageDir()) &&
            !empty($this->getMode())
        );
    }

    /**
     * @return mixed
     */
    public function getClientId()
    {
        return $this->clientId;
    }

    /**
     * @param mixed $clientId
     *
     * @return mixed
     */
    public function setClientId($clientId)
    {
        $this->clientId = $clientId;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getClientSecret()
    {
        return $this->clientSecret;
    }

    /**
     * @param mixed $clientSecret
     *
     * @return mixed
     */
    public function setClientSecret($clientSecret)
    {
        $this->clientSecret = $clientSecret;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getMode()
    {
        return $this->mode;
    }

    /**
     * @param mixed $mode
     *
     * @return $this
     */
    public function setMode($mode)
    {
        $this->mode = $mode;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getUrlSuccess()
    {
        return $this->urlSuccess;
    }

    /**
     * @param mixed $urlSuccess
     *
     * @return $this
     */
    public function setUrlSuccess($urlSuccess)
    {
        $this->urlSuccess = $urlSuccess;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getUrlFailure()
    {
        return $this->urlFailure;
    }

    /**
     * @param mixed $urlFailure
     *
     * @return $this
     */
    public function setUrlFailure($urlFailure)
    {
        $this->urlFailure = $urlFailure;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getUrlNotify()
    {
        return $this->urlNotify;
    }

    /**
     * @param mixed $urlNotify
     *
     * @return $this
     */
    public function setUrlNotify($urlNotify)
    {
        $this->urlNotify = $urlNotify;

        return $this;
    }

    /**
     * @return string
     */
    public function getStorageDir()
    {
        return $this->storageDir;
    }

    /**
     * @param string $storageDir
     *
     * @return $this
     */
    public function setStorageDir($storageDir)
    {
        $this->storageDir = $storageDir;

        return $this;
    }
}
